=============
Pynamodb Rest
=============


.. image:: https://img.shields.io/pypi/v/pynamodb_rest.svg
        :target: https://pypi.python.org/pypi/pynamodb_rest

.. image:: https://img.shields.io/travis/ndanielsen/pynamodb_rest.svg
        :target: https://travis-ci.org/ndanielsen/pynamodb_rest

.. image:: https://readthedocs.org/projects/pynamodb-rest/badge/?version=latest
        :target: https://pynamodb-rest.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




A Python based project to easily serve up serverless REST apis utilizing the wonderful Pynamodb package


* Free software: MIT license
* Documentation: https://pynamodb-rest.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
